import { RevealBoundaryStore } from './RevealBoundryStore.js';
import { config } from './config.js';
export class RevealStateManager {
    constructor() {
        this._currentHashId = 0;
        this._storage = [];
        this.requestedTraverseBoundaries = false;
        this.cachedMouseX = -1;
        this.cachedMouseY = -1;
        this.handlePointerMove = (event) => {
            this.cachedMouseX = event.clientX;
            this.cachedMouseY = event.clientY;
            if (!this.requestedTraverseBoundaries) {
                window.requestAnimationFrame(this.traverseBoundaries);
                this.requestedTraverseBoundaries = true;
            }
        };
        this.traverseBoundaries = () => {
            this.requestedTraverseBoundaries = false;
            for (let i = 0; i < this._storage.length; i++) {
                this._storage[i].onPointerMoveOnScreen(this.cachedMouseX, this.cachedMouseY);
            }
        };
        this.newBoundary = ($el) => {
            const hashId = this._currentHashId++;
            const store = new RevealBoundaryStore(hashId, $el);
            this._storage.push(store);
            return store;
        };
        this.removeBoundary = (store) => {
            this._storage = this._storage.filter((x) => x !== store);
        };
        if (config.borderDetectionMode === 'experimentalAutoFit') {
            if (typeof Window === 'undefined')
                return;
            window.addEventListener('pointermove', this.handlePointerMove);
            window.addEventListener('pointerdown', this.handlePointerMove);
            window.addEventListener('touchend', () => {
                for (let i = 0; i < this._storage.length; i++) {
                    this._storage[i].onPointerLeaveBoundary();
                }
            });
        }
    }
}
//# sourceMappingURL=RevealStateManager.js.map